==> tencentcloud-sdk-python-3.0.705.tar.gz: tencentcloud-sdk-python-3.0.705/tencentcloud/dataintegration/v20220613/dataintegration_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.dataintegration.v20220613 import models


class DataintegrationClient(AbstractClient):
    _apiVersion = '2022-06-13'
    _endpoint = 'dataintegration.tencentcloudapi.com'
    _service = 'dataintegration'


    def SendMessage(self, request):
        """使用SDK将数据上报到DIP

        :param request: Request instance for SendMessage.
        :type request: :class:`tencentcloud.dataintegration.v20220613.models.SendMessageRequest`
        :rtype: :class:`tencentcloud.dataintegration.v20220613.models.SendMessageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SendMessage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SendMessageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)

==> tencentcloud-sdk-python-3.0.1418.tar.gz: tencentcloud-sdk-python-3.0.1418/tencentcloud/dataintegration/v20220613/dataintegration_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.dataintegration.v20220613 import models


class DataintegrationClient(AbstractClient):
    _apiVersion = '2022-06-13'
    _endpoint = 'dataintegration.tencentcloudapi.com'
    _service = 'dataintegration'


    def SendMessage(self, request):
        """使用SDK将数据上报到DIP

        :param request: Request instance for SendMessage.
        :type request: :class:`tencentcloud.dataintegration.v20220613.models.SendMessageRequest`
        :rtype: :class:`tencentcloud.dataintegration.v20220613.models.SendMessageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SendMessage", params, headers=headers)
            response = json.loads(body)
            model = models.SendMessageResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))
